@@ -303,6 +303,11 @@ def compute_gene_psi(gene_ids, gff_index_filename, bam_filename, output_dir,
 
     if settings and "sam_template" in settings:
         template = settings["sam_template"]
+
+    if "filter_reads" not in settings:
+        filter_reads = True
+    else:
+        filter_reads = settings["filter_reads"]
         
     # Load the BAM file upfront
     bamfile = sam_utils.load_bam_reads(bam_filename, template=template)
@@ -331,10 +336,11 @@ def compute_gene_psi(gene_ids, gff_index_filename, bam_filename, output_dir,
                                                          paired_end=paired_end)
                                    
         # Skip gene if none of the reads align to gene boundaries
-        if num_raw_reads < min_event_reads:
-            print "Only %d reads in gene, skipping (needed >= %d reads)" \
-                  %(num_raw_reads, min_event_reads)
-            continue
+        if filter_reads:
+            if num_raw_reads < min_event_reads:
+                print "Only %d reads in gene, skipping (needed >= %d reads)" \
+                      %(num_raw_reads, min_event_reads)
+                continue
 
         num_isoforms = len(gene_obj.isoforms)
         hyperparameters = ones(num_isoforms)
@@ -415,6 +421,11 @@ def main():
                       "Expects three directories: the first is sample1's MISO output, "
                       "the second is sample2's MISO output, and the third is the directory where "
 		      "results of the sample comparison will be outputted.")
+    parser.add_option("--comparison-labels", dest="comparison_labels", nargs=2, default=None,
+                      help="Use these labels for the sample comparison made by --compare-samples. "
+                      "Takes two arguments: the label for sample 1 and the label for sample 2, "
+                      "where sample 1 and sample 2 correspond to the order of samples given "
+                      "to --compare-samples.")
     parser.add_option("--run-two-iso-event", dest="run_two_iso_event", nargs=3, default=None,
 		      help="Run MISO on two isoform event, given an event name, an events file "
                       "(in JSON/Pickle format) and an output directory.")
@@ -422,6 +433,9 @@ def main():
 		      help="Compute summary statistics of the given set of samples. "
                       "Expects a directory with MISO output and a directory to output "
                       "summary file to.")
+    parser.add_option("--summary-label", dest="summary_label", nargs=1, default=None,
+                      help="Label for MISO summary file. If not given, uses basename of MISO output "
+                      "directory.")
     parser.add_option("--summarize-multi-iso-samples", dest="summarize_samples", nargs=2, default=None,
 		      help="Compute summary statistics of the given set of samples from multi-isoform runs. "
                       "Expects a directory with MISO output and a directory to output summary file to.")
@@ -458,7 +472,8 @@ def main():
             print "Making comparisons directory: %s" %(output_dirname)
 	    os.makedirs(output_dirname)
 	ht.output_samples_comparison(sample1_dirname, sample2_dirname,
-                                     output_dirname)
+                                     output_dirname,
+                                     sample_labels=options.comparison_labels)
 	
     if options.run_two_iso_event:
 	if options.read_len == None or options.overhang_len == None:
@@ -547,7 +562,11 @@ def main():
     ##
     if options.summarize_samples:
 	samples_dir = os.path.abspath(os.path.expanduser(options.summarize_samples[0]))
-	samples_label = os.path.basename(os.path.expanduser(samples_dir))
+        if options.summary_label != None:
+            samples_label = options.summary_label
+            print "Using summary label: %s" %(samples_label)
+        else:
+            samples_label = os.path.basename(os.path.expanduser(samples_dir))
 	assert(len(samples_label) >= 1)
 	summary_output_dir = os.path.abspath(os.path.join(os.path.expanduser(options.summarize_samples[1]),
 							  'summary'))
